@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.002';
+$Time::C::VERSION = '0.003';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -369,7 +369,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -391,7 +391,7 @@ version 0.002
 
   # print all days of the week (2016-02-29T00:00:00Z to 2016-03-06T00:00:00Z)
   $t->day_of_week = 1;
-  do { say $t } while ($t->day_of_week++ > 1);
+  do { say $t } while ($t->day_of_week++ < 7);
 
 =head1 DESCRIPTION
 
